pub enum LineSearchAlgorithm {
MoreThuente,
BackTrackingArmijo,
BackTrackingStrongWolfe,
BackTrackingWolfe,
}Expand description
Line search algorithms.
Variants
MoreThuente
MoreThuente method proposd by More and Thuente. This is the default for regular LBFGS.
BackTrackingArmijo
BackTracking method with the Armijo condition.
The backtracking method finds the step length such that it satisfies the sufficient decrease (Armijo) condition,
- f(x + a * d) <= f(x) + ftol * a * g(x)^T d,
where x is the current point, d is the current search direction, and a is the step length.
BackTrackingStrongWolfe
BackTracking method with strong Wolfe condition.
The backtracking method finds the step length such that it satisfies both the Armijo condition (BacktrackingArmijo) and the following condition,
- |g(x + a * d)^T d| <= gtol * |g(x)^T d|,
where x is the current point, d is the current search direction, and a is the step length.
BackTrackingWolfe
BackTracking method with regular Wolfe condition.
The backtracking method finds the step length such that it satisfies both the Armijo condition (BacktrackingArmijo) and the curvature condition,
- g(x + a * d)^T d >= gtol * g(x)^T d,
where x is the current point, d is the current search direction, and a is the step length.